require 'nokogiri'
require 'open-uri'
require 'pry'

class UnknownTeamError < StandardError; end

module NpbApi
  class Player
    TEAMS = %w[g t c d db s h bs f m l e]

    def self.list(team: nil)
      raise UnknownTeamError unless TEAMS.include?(team)
      source(team).css('tr.rosterPlayer').each_with_object([]) do |row, arr|
        next if row.css('td.rosterRegister a').empty?
        row.css('td.rosterRegister a').attr('href').text =~ /\/players\/(\d+)\.html/
        arr << new(id: $1, note: row.css('td.rosterdetail').text)
      end
    end

    def self.all
      TEAMS.each_with_object([]) do |team, arr|
        arr << list(team: team)
      end.flatten
    end

    def self.source(team)
      Nokogiri::HTML(open(url(team)))
    end

    def self.url(team)
      "http://bis.npb.or.jp/teams/rst_#{team}.html"
    end

    private_class_method :source, :url

    attr_accessor :note

    def initialize(id: nil, note: nil)
      @id = id
      @note = note
    end

    def team
      header.css('.registerTeam').text
    end

    def name
      header.css('.registerPlayer').text
    end

    def number
      header.css('.registerNo').text
    end

    def position
      header.css('.registerPosition').text
    end

    def kana
      detail[0].text
    end

    def birthday
      detail[1].text.split('　　')[0] =~ /\A(\d{4})年(\d{1,2})月(\d{1,2})日生\z/
      Date.new($1.to_i, $2.to_i, $3.to_i)
    end

    def height
      detail[1].text.split('　　')[1] =~ /\A身長(\d{3})cm\z/
      $1.to_i
    end

    def weight
      detail[1].text.split('　　')[2] =~ /\A体重(\d{2,3})kg\z/
      $1.to_i
    end

    def hand
      detail[1].text.split('　　')[3]
    end

    def career
      detail[2].text
    end

    def draft
      detail[3].text
    end

    private

    def url
      "http://bis.npb.or.jp/players/#{@id}.html"
    end

    def source
      Nokogiri::HTML(open(url))
    end

    def header
      @header ||= source.css('#registerdivheader')
    end

    def detail
      @detail ||= header.css('.registerDetail')
    end
  end
end
