require 'nokogiri'
require 'open-uri'
require 'pry'

class UnknownLeagueError < StandardError; end
class UnknownTeamError < StandardError; end

module NpbApi
  module Stats
    class Base
      TEAMS = %w[g t c d db s h bs f m l e]
      LEAGUES = %w[central pacific eastern western]
      TEAM_LEAGUES = [
        { team: 'g',  leagues: %w[central eastern] },
        { team: 't',  leagues: %w[central western] },
        { team: 'c',  leagues: %w[central western] },
        { team: 'd',  leagues: %w[central western] },
        { team: 'db', leagues: %w[central eastern] },
        { team: 's',  leagues: %w[central eastern] },
        { team: 'h',  leagues: %w[pacific western] },
        { team: 'bs', leagues: %w[pacific western] },
        { team: 'f',  leagues: %w[pacific eastern] },
        { team: 'm',  leagues: %w[pacific eastern] },
        { team: 'l',  leagues: %w[pacific eastern] },
        { team: 'e',  leagues: %w[pacific eastern] }
      ]

      def self.list(team, league, year)
        raise UnknownTeamError unless TEAMS.include?(team)
        raise UnknownLeagueError unless LEAGUES.include?(league)
        source(team, league, year).css('tr.ststats').each_with_object([]) do |row, arr|
          arr << new(row, team, league, year)
        end
      end

      def self.all(year)
        TEAM_LEAGUES.each_with_object([]) do |team_leagues, arr|
          team_leagues[:leagues].each do |league|
            arr << list(team_leagues[:team], league, year)
          end
        end.flatten
      end

      def self.source(team, league, year)
        Nokogiri::HTML(open(url(team, league, year)))
      end

      def self.url(team, league, year)
        case league
        when 'central', 'pacific'
          "http://bis.npb.or.jp/#{year}/stats/id#{url_key}1_#{team}.html"
        when 'eastern', 'western'
          "http://bis.npb.or.jp/#{year}/stats/id#{url_key}2_#{team}.html"
        end
      end

      def self.url_key
        raise NotImplementedError
      end

      private_class_method :source, :url, :url_key

      attr_reader :team, :league, :year

      def initialize(row, team, league, year)
        @row = row
        @team = team
        @league = league
        @year = year
      end
    end
  end
end
