module NpbApi
  module Stats
    class Fielding < Base
      def self.list(team, league, year)
        raise UnknownTeamError unless TEAMS.include?(team)
        raise UnknownLeagueError unless LEAGUES.include?(league)
        position = ''
        source(team, league, year).css('#stdivmaintbl tr').each_with_object([]) do |row, arr|
          position = new_position(row) unless row.css('th.sthdfplayer').empty?
          arr << new(row, team, league, year, position) if ststats?(row)
        end
      end

      def self.ststats?(row)
        !row.attributes['class'].nil? && row.attributes['class'].value == 'ststats'
      end

      def self.new_position(row)
        row.css('th.sthdfplayer').text =~ /【(.+)】/; $1
      end

      def self.url_key
        'f'
      end

      private_class_method :ststats?, :new_position

      attr_reader :position

      def initialize(row, team, league, year, position)
        @row = row
        @team = team
        @league = league
        @year = year
        @position = position
      end

      def player
        @row.children[3].children.text
      end

      def games
        @row.children[5].children.text.to_i
      end

      def put_outs
        @row.children[7].children.text.to_i
      end

      def assists
        @row.children[9].children.text.to_i
      end

      def errors
        @row.children[11].children.text.to_i
      end

      def double_plays
        @row.children[13].children.text.to_i
      end

      def passed_ball
        value = @row.children[15].children.text
        value == '' ? nil : value.to_i
      end

      def fielding_average
        @row.children[17].children.text.to_f
      end
    end
  end
end
