module NpbApi
  module Stats
    class Pitching < Base
      def self.url_key
        'p'
      end

      def player
        @row.children[2].text
      end

      def games
        @row.children[4].text.to_i
      end

      def wins
        @row.children[5].text.to_i
      end

      def loses
        @row.children[6].text.to_i
      end

      def saves
        @row.children[7].text.to_i
      end

      def holds
        return nil if farm?
        @row.children[8].text.to_i
      end

      def hold_points
        return nil if farm?
        @row.children[9].text.to_i
      end

      def complete_games
        line = (farm? ? 8 : 10)
        @row.children[line].text.to_i
      end

      def shutouts
        line = (farm? ? 9 : 11)
        @row.children[line].text.to_i
      end

      def without_walking
        line = (farm? ? 10 : 12)
        @row.children[line].text.to_i
      end

      def winning_percentage
        line = (farm? ? 12 : 14)
        @row.children[line].text.to_f
      end

      def total_batters_faced
        line = (farm? ? 13 : 15)
        @row.children[line].text.to_i
      end

      def innings_pitched
        line1, line2 = (farm? ? [14, 15] : [16, 17])
        (@row.children[line1].text + @row.children[line2].text).to_f
      end

      def hits
        line = (farm? ? 16 : 18)
        @row.children[line].text.to_i
      end

      def home_runs
        line = (farm? ? 18 : 20)
        @row.children[line].text.to_i
      end

      def walks
        line = (farm? ? 19 : 21)
        @row.children[line].text.to_i
      end

      def intentional_walks
        line = (farm? ? 20 : 22)
        @row.children[line].text.to_i
      end

      def hit_by_pitch
        line = (farm? ? 21 : 23)
        @row.children[line].text.to_i
      end

      def strikeouts
        line = (farm? ? 22 : 24)
        @row.children[line].text.to_i
      end

      def wild_pitches
        line = (farm? ? 23 : 25)
        @row.children[line].text.to_i
      end

      def balks
        line = (farm? ? 24 : 26)
        @row.children[line].text.to_i
      end

      def runs
        line = (farm? ? 25 : 27)
        @row.children[line].text.to_i
      end

      def earned_runs
        line = (farm? ? 26 : 28)
        @row.children[line].text.to_i
      end

      def earned_run_average
        line = (farm? ? 27 : 29)
        @row.children[line].text.to_f
      end

      private

      def farm?
        %w[eastern western].include?(league)
      end
    end
  end
end
