require 'nokogiri'
require 'open-uri'
require 'pry'

module NpbApi
  module Stats
    class Team
      def self.list(league, year)
        regular_reague = source(league, year).css('table.stdtblSubmain')[0]
        regular_reague.css('tr[align="center"]').each_with_object([]) do |row, arr|
          next if row.css('td.stdTeam').empty? # 行にチーム名が含まれていなかったらスキップ
          arr << new(row, league, year)
        end
      end

      def self.source(league, year)
        Nokogiri::HTML(open(url(league, year)))
      end

      def self.url(league, year)
        "http://bis.npb.or.jp/#{year}/stats/std_#{league}.html"
      end

      private_class_method :source, :url

      attr_reader :year

      def initialize(row, league, year)
        @row = row
        @league = league
        @year = year
      end

      def league
        case @league
        when 'c' then 'central'
        when 'p' then 'pacific'
        when 'e' then 'eastern'
        when 'w' then 'western'
        end
      end

      def team
        @row.css('td.stdTeam').text.gsub(/　/, '')
      end

      def games
        @row.css('td.stdscore')[0].text.to_i
      end

      def wins
        @row.css('td.stdscore')[1].text.to_i
      end

      def loses
        @row.css('td.stdscore')[2].text.to_i
      end

      def draws
        @row.css('td.stdscore')[3].text.to_i
      end

      def winning_percentage
        @row.css('td.stdscore')[4].text.to_f
      end

      def games_behind
        @row.css('td.stdscore')[5].text
      end
    end
  end
end
